## Reference Prompts Examples Used for Inference

1. MP3 files are from ElevenLabs voice library, named same as Voice ID, WAV files are from [Habibi benchmark](https://huggingface.co/datasets/SWivid/Habibi). See the [Habibi paper](https://arxiv.org/abs/2601.13802) for more details.
2. The terminology does not reflect any official classification for Arabic. Each sample is just for example, only reflects a part of the corresponding ID.


### MSA (Modern Standard Arabic)
```bash
# MSA.mp3 (JjTirzdD7T3GMLkwdd3a)
"كان اللعيب حاضرًا في العديد من الأنشطة والفعاليات المرتبطة بكأس العالم، مما سمح للجماهير بالتفاعل معه والتقاط الصور التذكارية."
```

### SAU (Najdi, Hijazi, Gulf, etc.)
```bash
# Najdi.wav (6k_SBA_22_2-seg_410_975-416_518)
"تكفى طمني انا اليوم ماني بنايم ولا هو بداخل عيني النوم الين اتطمن عليه."

# Hijazi.wav (6k_SBA_27_0-seg_544_950-550_440)
"ابغاك تحقق معاه بس بشكل ودي لانه سلطان يمر بظروف صعبة شوية."

# Gulf.wav (6k_SBA_107_1-seg_22_960-29_010)
"وين تو الناس متى تصحى ومتى تفطر وتغير يبيلك ساعة يعني بالله تروح الشغل الساعة عشره."
```

### UAE (Emirati)
```bash
# UAE.wav (13_segment_108)
"قمنا نشتريها بشكل متكرر أو لما نلقى ستايل يعجبنا وحياناً هذا الستايل ما نحبه."
```

### ALG (Algerian & Algerian Saharan)
```bash
# ALG.wav (yCfWAGx6aTw-162)
"أنيا هكا باغية ناكل هكا أني ن نشوف فيها الحاجة هذيكا."
```

### IRQ (Mesopotamian & North Mesopotamian)
```bash
# IRQ.wav (P9zYhlu5pzw-613)
"يعني ااا ما نقدر ناخذ وقت أكثر، ااا لأنه شروط كلش يحتاجلها وقت."
```

### EGY (Egyptian, Saidi, etc.)
```bash
# EGY.mp3 (IES4nrmZdUBHByLBde0P)
"ايه الكلام. بقولك ايه. استخدم صوتي في المحادثات. استخدمه هيعجبك اوي."
```

### MAR (Moroccan or Darija)
```bash
# MAR.mp3 (OfGMGmhShO8iL9jCkXy8)
"إذا بغيتي شي صوت باللهجة المغربية للإعلانات ديالك هذا أحسن واحد غادي تلقاه."
```

### OMN (Omani, Dhofari, etc.)
N/A

### TUN (Tunisian)
N/A

### LEV (Levantine)
N/A

### SDN (Sudanese)
N/A

### LBY (Libyan)
N/A

### UNK (Unknown)
N/A
